desk package — Dusty-Evolved-Star-Kit 1.6.24 documentation

# desk package

## Submodules

## desk.fitting module

## desk.probabilities module

## desk.set_up module

## desk.tests module

## Module contents

The DESK contains python packages that are bundled with the package but are external to it, and hence are developed in a separate source tree. Note that this package is distinct from the /cextern directory of the source code distribution, as that directory only contains C extension code.